@@ -1,20 +1,20 @@
 `NONR` <-  
 function (
-	run,
+	run, 
 	...,
 	command, 
 	project = getwd(), 
 	wait = TRUE,
-	grid = FALSE,
+	grid = FALSE, 
 	concurrent = grid & wait,
 	udef= FALSE, 
 	invisible=udef,
 	compile = TRUE,
 	execute = TRUE,
-	split = grid & compile & execute,
+	split = FALSE,
 	checkrunno = TRUE, 
 	checksum = TRUE, 
-	diag = wait,
+	diag = wait, 
 	fdata = TRUE, 
 	logtrans = FALSE,
 	nice= TRUE, 
@@ -26,7 +26,10 @@ function (
 	cat.cov = NULL, 
 	par.list = NULL, 
 	eta.list = NULL, 
-	missing = -99
+	missing = -99, 
+	interface='autolog.pl',
+	q='all.q',
+	pe=NA
 ){
     if (win())  grid <- FALSE
     if (win())  concurrent <- FALSE
@@ -45,16 +48,26 @@ function (
     	command <- candidate
     }    
     args <- list(
-	run = run, 
+	run = run,
+	...,
 	command = command, 
 	project = project, 
 	wait = wait,
+	grid = grid, 
+	# concurrent used only in this scope
+	udef = udef, 
+	invisible = invisible, 
+	compile = compile,
+	execute = execute,
+	split = split,
 	checkrunno = checkrunno, 
+	checksum = checksum, 
 	diag = diag, 
 	fdata = fdata, 
+	logtrans = logtrans, 
+	nice = nice,
 	epilog = epilog, 
 	dvname = dvname, 
-	logtrans = logtrans, 
 	grp = grp, 
 	grpnames = grpnames, 
 	cont.cov = cont.cov, 
@@ -62,15 +75,9 @@ function (
 	par.list = par.list, 
 	eta.list = eta.list, 
 	missing = missing,
-	invisible = invisible, 
-	checksum = checksum, 
-	grid = grid, 
-	nice = nice,
-	udef = udef, 
-	split = split,
-	compile = compile,
-	execute = execute,
-	...
+	interface = interface,
+	q = q,
+	pe = pe
     )
     res <- lapply(
     	run,
@@ -102,67 +109,4 @@ function (
 }
 nix <- function().Platform$OS.type == 'unix'
 win <- function().Platform$OS.type == 'windows'
-NONR72 <- function(
-	run, 
-	...,
-	command, 
-	project = getwd(), 
-	wait = TRUE,
-	grid = FALSE, 
-	concurrent = grid & wait,
-	udef= FALSE, 
-	invisible=udef,
-	compile = TRUE,
-	execute = TRUE,
-	split = FALSE,
-	checkrunno = TRUE, 
-	checksum = TRUE, 
-	diag = wait, 
-	fdata = TRUE, 
-	logtrans = FALSE,
-	nice= TRUE, 
-	epilog = NULL, 
-	dvname = NULL, 
-	grp = NULL, 
-	grpnames = NULL, 
-	cont.cov = NULL, 
-	cat.cov = NULL, 
-	par.list = NULL, 
-	eta.list = NULL, 
-	missing = -99, 
-	interface='autolog.pl',
-	q='all.q',
-	pe=NA
-)NONR(
-	run=run,
-	command=command,
-	project=project,
-	wait=wait,
-	grid=grid,
-	concurrent=concurrent,
-	udef=udef,
-	invisible=invisible,
-	compile=compile,
-	execute=execute,
-	split=split,
-	checkrunno=checkrunno,
-	checksum=checksum,
-	diag=diag,
-	fdata=fdata,
-	logtrans=logtrans,
-	nice=nice,
-	epilog=epilog,
-	dvname=dvname,
-	grp=grp,
-	grpnames=grpnames,
-	cont.cov=cont.cov,
-	cat.cov=cat.cov,
-	par.list=par.list,
-	eta.list=eta.list,
-	missing= missing,
-	interface=interface,
-	q=q,
-	pe=pe,
-	...
-)
 
