@@ -14,7 +14,11 @@ reapply <-
     val <- lapply(vals, FUN, ...)
     dim <- table(INDEX)
     val <- lapply(seq_along(val),function(i)rep(val[[i]], length.out=dim[[i]]))
-    split(x,INDEX) <- val
-    x[is.na(INDEX)] <- NA
-    x
+    t <- NA # default to logical
+    if(length(val)) if(length(val[[1]])) t <- val[[1]][[1]] # sample type given by FUN
+    t[[1]] <- NA # ensure non-informative
+    y <- rep(t[[1]],length(x))
+    split(y,INDEX) <- val # minimal bias with respect to class
+    y[is.na(INDEX)] <- NA # probably true already
+    y
   }
